@@ -80,12 +80,9 @@ class Model:
                 return w
             return True
         except FileNotFoundError:
-            print(
-                f"There is no model with the name '{self.__modelname}' in your folder '{os.getcwd()}'.\n"
-            )
-            print(f"Your model should be of a python file: '{self.__modelname}.py'")
-            text = colored("Model upload failed!", "red")
+            text = colored(f"Upload failed. There is no model with the name '{self.__modelname}' in your folder '{os.getcwd()}'.", "red")
             print(text, "\n")
+            print("For more information check the docs 'https://docs.tracebloc.io/user-uploadModel'")
             return False
 
     def checkWeights(self):
@@ -93,12 +90,11 @@ class Model:
         try:
             weights_file = open(self.__weights_path, "rb")
         except FileNotFoundError:
-            print(f"The model weights file does not meet the convention.")
-            print(
-                f"Expected weights name: '{self.__modelname}_weights.pkl'.\nPlease check your model weights file name."
-            )
-            text = colored("\nWeights upload failed!", "red")
+            text = colored(
+                f"Weights Upload failed. No weights file found with the name '{self.__modelname}_weights.pkl' in path '{os.getcwd()}'.",
+                "red")
             print(text, "\n")
+            print("For more information check the docs 'https://docs.tracebloc.io/user-uploadModel'")
             return False
         # Load weights to check if it works
         try:
@@ -112,13 +108,12 @@ class Model:
             return True
         except ValueError:
             weights_file.close()
-            text = colored("Weights not compatible with model.", "red")
-            print(text, "\n")
             text = colored(
-                "Weights upload failed! Provide weights compatible with provided model!",
+                "Weights upload failed. Provide weights compatible with provided model.",
                 "red",
             )
             print(text, "\n")
+            print("For more information check the docs 'https://docs.tracebloc.io/weights'")
             return False
 
     def upload(self):
