@@ -123,12 +123,7 @@ class User:
                 print(text, "\n")
                 self.__weights = False
         except:
-            if weights:
-                text = colored(f"Model and Weights upload Failed.", "red")
-                print(text, "\n")
-            else:
-                text = colored(f"Model upload Failed.", "red")
-                print(text, "\n")
+            return
 
     def linkModelDataset(self, datasetId: str):
 
@@ -236,3 +231,5 @@ class User:
 
         print("linkModelDataset():")
         print("Link uploaded model with a dataset.\n")
+
+        print("For more information check docs 'https://docs.tracebloc.io/'")
